@@ -9,7 +9,7 @@ rm -rf nss/.git*
 
 VERSION=`dpkg-parsechangelog -l nss/debian/changelog | grep Version | sed 's/.* //'`
 
-git add nss
+git add -f nss
 git commit -m "Refresh nss
 
 Package version: $VERSION
